==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_14.js <==
var searchData=
[
  ['objects_0',['C++ standard stream objects',['../contributing_guidelines.html#autotoc_md64',1,'']]],
  ['of_20amd_20and_20nvidia_1',['HIP platform detection of AMD and NVIDIA',['../install_ginkgo.html#autotoc_md4',1,'']]],
  ['of_20contents_2',['Table of Contents',['../contributing_guidelines.html#autotoc_md18',1,'']]],
  ['of_20macros_20vs_20functions_3',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
  ['of_20this_20approach_20and_20usage_4',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
  ['on_20github_20and_20analyze_20the_20results_20with_20the_20gpe_20optional_5',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['on_20portability_6',['On Portability',['../citing_ginkgo.html#autotoc_md68',1,'']]],
  ['on_20software_20sustainability_7',['On Software Sustainability',['../citing_ginkgo.html#autotoc_md69',1,'']]],
  ['on_20spmv_20or_20solvers_20performance_8',['On SpMV or solvers performance',['../citing_ginkgo.html#autotoc_md70',1,'']]],
  ['operations_9',['operations',['../classgko_1_1range.html#autotoc_md78',1,'Compound operations'],['../classgko_1_1range.html#autotoc_md77',1,'Range operations']]],
  ['operator_20as_20a_20concept_10',['operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'Batched Linear operator as a concept'],['../group__LinOp.html#linop_concept',1,'Linear operator as a concept']]],
  ['optional_11',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['options_12',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['or_20solvers_20performance_13',['On SpMV or solvers performance',['../citing_ginkgo.html#autotoc_md70',1,'']]],
  ['other_20code_20formatting_20not_20handled_20by_20clangformat_14',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md44',1,'']]],
  ['other_20packages_15',['Changing the paths to search for HIP and other packages',['../install_ginkgo.html#autotoc_md3',1,'']]],
  ['other_20programming_20comments_16',['Other programming comments',['../contributing_guidelines.html#autotoc_md63',1,'']]],
  ['our_20git_20workflow_17',['Our git workflow',['../contributing_guidelines.html#autotoc_md24',1,'']]],
  ['overhead_20program_18',['The ginkgo-overhead program',['../ginkgo_overhead.html',1,'']]],
  ['overview_19',['4: Benchmarking overview',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_14.js <==
var searchData=
[
  ['objects_0',['C++ standard stream objects',['../contributing_guidelines.html#autotoc_md64',1,'']]],
  ['of_20amd_20and_20nvidia_1',['HIP platform detection of AMD and NVIDIA',['../install_ginkgo.html#autotoc_md4',1,'']]],
  ['of_20contents_2',['Table of Contents',['../contributing_guidelines.html#autotoc_md18',1,'']]],
  ['of_20macros_20vs_20functions_3',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
  ['of_20this_20approach_20and_20usage_4',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
  ['on_20github_20and_20analyze_20the_20results_20with_20the_20gpe_20optional_5',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['on_20portability_6',['On Portability',['../citing_ginkgo.html#autotoc_md68',1,'']]],
  ['on_20software_20sustainability_7',['On Software Sustainability',['../citing_ginkgo.html#autotoc_md69',1,'']]],
  ['on_20spmv_20or_20solvers_20performance_8',['On SpMV or solvers performance',['../citing_ginkgo.html#autotoc_md70',1,'']]],
  ['operations_9',['operations',['../classgko_1_1range.html#autotoc_md78',1,'Compound operations'],['../classgko_1_1range.html#autotoc_md77',1,'Range operations']]],
  ['operator_20as_20a_20concept_10',['operator as a concept',['../group__BatchLinOp.html#batch_linop_concept',1,'Batched Linear operator as a concept'],['../group__LinOp.html#linop_concept',1,'Linear operator as a concept']]],
  ['optional_11',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['options_12',['7: Available benchmark options',['../benchmarking_ginkgo.html#autotoc_md17',1,'']]],
  ['or_20run_5fall_5fbenchmarks_20sh_13',['4: Benchmarking with &lt;span class=&quot;tt&quot;&gt;make benchmark&lt;/span&gt; or &lt;span class=&quot;tt&quot;&gt;run_all_benchmarks.sh&lt;/span&gt;',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['or_20solvers_20performance_14',['On SpMV or solvers performance',['../citing_ginkgo.html#autotoc_md70',1,'']]],
  ['other_20code_20formatting_20not_20handled_20by_20clangformat_15',['Other Code Formatting not handled by ClangFormat',['../contributing_guidelines.html#autotoc_md44',1,'']]],
  ['other_20packages_16',['Changing the paths to search for HIP and other packages',['../install_ginkgo.html#autotoc_md3',1,'']]],
  ['other_20programming_20comments_17',['Other programming comments',['../contributing_guidelines.html#autotoc_md63',1,'']]],
  ['our_20git_20workflow_18',['Our git workflow',['../contributing_guidelines.html#autotoc_md24',1,'']]],
  ['overhead_20program_19',['The ginkgo-overhead program',['../ginkgo_overhead.html',1,'']]]
];
